@@ -105,7 +105,6 @@ from . import adapter_sheppardweircom
 from . import adapter_samandjacknet
 from . import adapter_csiforensicscom
 from . import adapter_lotrfanfictioncom
-from . import adapter_fhsarchivecom
 from . import adapter_fanfictionjunkiesde
 from . import adapter_tgstorytimecom
 from . import adapter_itcouldhappennet
@@ -136,7 +135,6 @@ from . import adapter_sugarquillnet
 from . import adapter_starslibrarynet
 from . import adapter_fanficauthorsnet
 from . import adapter_fireflyfansnet
-from . import adapter_fireflypopulliorg
 from . import adapter_sebklainenet
 from . import adapter_shriftweborgbfa
 from . import adapter_trekfanfictionnet
@@ -169,6 +167,7 @@ from . import adapter_wwwnovelallcom
 from . import adapter_wuxiaworldco
 from . import adapter_harrypotterfanfictioncom
 from . import adapter_hentaifoundrycom
+from . import adapter_mugglenetfanfictioncom
 
 ## This bit of complexity allows adapters to be added by just adding
 ## importing.  It eliminates the long if/else clauses we used to need
